@@ -236,6 +236,17 @@ class SMTOtuApi
     	return sprintf( self::CMD_Is_MOD_Present_In_Cal, $module );
     }
     
+    const CMD_Get_Min_Attenuation_Alarm_Threshold= 'OTU:MON:ATT:TMIN? %s';
+    
+    /**
+     * @param string $module MOD1, MOD2 or MOD3
+     * @return string  
+     */
+    static function getMinAttenuationAlarmThreshold($module)
+    {
+    	return sprintf( self::CMD_Get_Min_Attenuation_Alarm_Threshold, $module );
+    }
+    
     /**
      * MOD3, MOD2 or MOD1
      */
